==> haskell-type-errors-pretty-0.0.1.2-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-errors-pretty
version:              0.0.1.2
visibility:           public
id:                   type-errors-pretty-0.0.1.2-CA20yESKimoEDhug2VfUnS
key:                  type-errors-pretty-0.0.1.2-CA20yESKimoEDhug2VfUnS
license:              MPL-2.0
copyright:
    2019-2020 Dmitrii Kovanikov
    2020-2021 Kowainik

maintainer:
    Dmitrii Kovanikov <kovanikov@gmail.com>
    Kowainik <xrom.xkov@gmail.com>

author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/type-errors-pretty
synopsis:             Combinators for writing pretty type errors easily
description:
    This library provides replacements for the @ErrorMessage@ constructors to
    write the text of custom error messages easily.

category:             Types, Type Errors
abi:                  55181303678915d9a51caabd15977cb8
exposed:              True
exposed-modules:      Type.Errors.Pretty
import-dirs:          /usr/lib/ghc-9.0.1/site-local/type-errors-pretty-0.0.1.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/type-errors-pretty-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/type-errors-pretty-0.0.1.2

hs-libraries:         HStype-errors-pretty-0.0.1.2-CA20yESKimoEDhug2VfUnS
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-type-errors-pretty/html/type-errors-pretty.haddock

haddock-html:         /usr/share/doc/haskell-type-errors-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-errors-pretty-0.0.1.2-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-errors-pretty
version:              0.0.1.2
visibility:           public
id:                   type-errors-pretty-0.0.1.2-uDATcVQ6MXAaOY7QNjGuE
key:                  type-errors-pretty-0.0.1.2-uDATcVQ6MXAaOY7QNjGuE
license:              MPL-2.0
copyright:
    2019-2020 Dmitrii Kovanikov
    2020-2021 Kowainik

maintainer:
    Dmitrii Kovanikov <kovanikov@gmail.com>
    Kowainik <xrom.xkov@gmail.com>

author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/type-errors-pretty
synopsis:             Combinators for writing pretty type errors easily
description:
    This library provides replacements for the @ErrorMessage@ constructors to
    write the text of custom error messages easily.

category:             Types, Type Errors
abi:                  11f633d22a457186f4e4d2ed2fa3a8a4
exposed:              True
exposed-modules:      Type.Errors.Pretty
import-dirs:          /usr/lib/ghc-9.0.1/site-local/type-errors-pretty-0.0.1.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/type-errors-pretty-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/type-errors-pretty-0.0.1.2

hs-libraries:         HStype-errors-pretty-0.0.1.2-uDATcVQ6MXAaOY7QNjGuE
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-type-errors-pretty/html/type-errors-pretty.haddock

haddock-html:         /usr/share/doc/haskell-type-errors-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
